AbiEncoder class

ABI encoder for Ethereum smart contract calls.

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

encode(List<AbiType> types, List values) Uint8List
Encodes values according to the given types.
encodeFunction(String signature, List args) Uint8List
Encodes a function call with selector and arguments.
encodePacked(List<AbiType> types, List values) Uint8List
Encodes values in packed format (no padding).
getEventTopic(String signature) Uint8List
Gets the 32-byte event topic from a signature. Per Solidity ABI specification, the signature is UTF-8 encoded before hashing.
getFunctionSelector(String signature) Uint8List
Gets the 4-byte function selector from a signature. Per Solidity ABI specification, the signature is UTF-8 encoded before hashing.