AbiParser class

Parser for ABI JSON definitions.

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

parseErrors(String abiJson) List<AbiError>
Parses errors from an ABI JSON string.
parseEvents(String abiJson) List<AbiEvent>
Parses events from an ABI JSON string.
parseFunctions(String abiJson) List<AbiFunction>
Parses functions from an ABI JSON string.
parseType(String typeStr) AbiType
Parses a type string into an AbiType.