validateFormat method
Validates that all authorizations in the batch are properly formatted.
Implementation
bool validateFormat() {
return _authorizations.every(_isValidFormat);
}
Validates that all authorizations in the batch are properly formatted.
bool validateFormat() {
return _authorizations.every(_isValidFormat);
}