Bech32 class

Bech32 encoding (BIP-173) for SegWit addresses.

Also supports Bech32m (BIP-350) for Taproot addresses.

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

decode(String address) → ({String hrp, Uint8List witnessProgram, int witnessVersion})
Decodes a Bech32/Bech32m address.
decodeGeneric(String address) → ({Uint8List data, String hrp})
Decodes a generic Bech32 address. Returns (hrp, data).
encode(String hrp, int witnessVersion, Uint8List witnessProgram) String
Encodes a witness program to a Bech32 address.
encodeGeneric(String hrp, Uint8List data) String
Encodes data to Bech32 address without version byte.