Block class

Block data.

Constructors

Block({required String hash, required String parentHash, required BigInt number, required BigInt timestamp, required String miner, required BigInt gasLimit, required BigInt gasUsed, required List<String> transactions, BigInt? baseFeePerGas})
Block.fromJson(Map<String, dynamic> json)
factory

Properties

baseFeePerGas BigInt?
final
gasLimit BigInt
final
gasUsed BigInt
final
hash String
final
hashCode int
The hash code for this object.
no setterinherited
miner String
final
number BigInt
final
parentHash String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
timestamp BigInt
final
transactions List<String>
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited