CallRequest class
Call request.
Constructors
Properties
- data → Uint8List?
-
final
- from → String?
-
final
- gasLimit → BigInt?
-
final
- gasPrice → BigInt?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- maxFeePerGas → BigInt?
-
final
- maxPriorityFeePerGas → BigInt?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- to → String?
-
final
- value → BigInt?
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited