Chains class

Pre-defined chain configurations.

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

arbitrum → ChainConfig
Arbitrum One.
final
avalanche → ChainConfig
Avalanche C-Chain.
final
base → ChainConfig
Base.
final
bitcoin → ChainConfig
Bitcoin Mainnet.
final
bsc → ChainConfig
BNB Smart Chain.
final
ethereum → ChainConfig
Ethereum Mainnet.
final
goerli → ChainConfig
Goerli Testnet (deprecated but still supported).
final
optimism → ChainConfig
Optimism.
final
polygon → ChainConfig
Polygon Mainnet.
final
sepolia → ChainConfig
Sepolia Testnet.
final
solana → ChainConfig
Solana Mainnet.
final

Static Methods

getAllChains() List<ChainConfig>
Gets all pre-defined chains.
getById(int chainId) → ChainConfig?
Gets a chain by ID.
registerChain(ChainConfig chain) → void
Registers a custom chain.
unregisterChain(int chainId) → void
Unregisters a custom chain.