ContractFactory class

Factory for creating and deploying contracts.

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

create({required String address, required String abi, required PublicClient publicClient, WalletClient? walletClient}) → Contract
Creates a contract instance.
deploy({required String bytecode, required WalletClient walletClient, String? abi, List constructorArgs = const [], BigInt? value, BigInt? gasLimit}) Future<DeployResult>
Deploys a new contract.
estimateDeployGas({required String bytecode, required PublicClient publicClient, required String from, List constructorArgs = const [], BigInt? value}) Future<BigInt>
Estimates gas for contract deployment.