ContractFunction class

Constructors

ContractFunction(String name, List<AbiType> parameters, {List<AbiType> outputs = const [], String stateMutability = 'nonpayable'})
const
ContractFunction.fromAbi(AbiFunction abi)

Properties

hashCode int
The hash code for this object.
no setterinherited
name String
final
outputs List<AbiType>
final
parameters List<AbiType>
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
signature String
no setter
stateMutability String
final

Methods

decodeReturnValues(Uint8List data) List
encodeCall(List params) Uint8List
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited