CurveFactory class
Factory class for creating curve instances.
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
createCurve(
String curveName) → CurveInterface - Creates a curve instance by name.
-
getSupportedCurves(
) → List< String> - Gets a list of all supported curve names.