DeployResult class
Result of a contract deployment.
Constructors
- DeployResult({required Contract contract, required String transactionHash, required TransactionReceipt receipt})
Properties
- address → String
-
The deployed contract address.
no setter
- contract → Contract
-
The deployed contract instance.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- receipt → TransactionReceipt
-
The deployment transaction receipt.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- transactionHash → String
-
The deployment transaction hash.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited