DeployedContract class

Constructors

DeployedContract(ContractAbi abi, EthereumAddress address)

Properties

abi ContractAbi
final
address EthereumAddress
final
events List<ContractEvent>
no setter
functions List<ContractFunction>
no setter
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

event(String name) ContractEvent
function(String name) ContractFunction
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited