EtherAmount class

Compatibility alias for web3dart's EtherAmount

Constructors

EtherAmount.fromBigInt(EtherUnit unit, BigInt value)
factory
EtherAmount.fromUnitAndValue(EtherUnit unit, BigInt value)
factory
EtherAmount.inWei(dynamic wei)
factory

Properties

getInWei BigInt
no setter
hashCode int
The hash code for this object.
no setterinherited
inWei BigInt
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

getValueInUnit(EtherUnit unit) → Decimal
getValueInUnitBI(EtherUnit unit) BigInt
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

zero() EtherAmount