EtherUnit enum

Compatibility alias for web3dart's EtherUnit

Inheritance
Available extensions

Values

wei → const EtherUnit
kwei → const EtherUnit
mwei → const EtherUnit
gwei → const EtherUnit
szabo → const EtherUnit
finney → const EtherUnit
ether → const EtherUnit

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
weiValue BigInt
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<EtherUnit>
A constant List of the values in this enum, in order of their declaration.