HardwareWalletSigner class abstract

Abstract hardware wallet signer interface.

Implemented types

Constructors

HardwareWalletSigner()

Properties

address EthereumAddress
The signer's Ethereum address.
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

connect() Future<void>
Connects to the hardware wallet.
disconnect() Future<void>
Disconnects from the hardware wallet.
getAddresses({int count = 5, int offset = 0}) Future<List<EthereumAddress>>
Gets available addresses from the hardware wallet.
isConnected() Future<bool>
Checks if the hardware wallet is connected.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
signAuthorization(Authorization authorization) Future<Uint8List>
Signs an EIP-7702 authorization.
inherited
signHash(Uint8List hash) Future<Uint8List>
Signs a raw hash directly without any prefix.
inherited
signMessage(String message) Future<Uint8List>
Signs a personal message (EIP-191).
inherited
signTransaction(TransactionRequest transaction) Future<Uint8List>
Signs a transaction and returns the signed transaction bytes.
inherited
signTypedData(EIP712TypedData typedData) Future<Uint8List>
Signs typed data (EIP-712).
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited