HexUtils class
Hex encoding/decoding utilities
Constructors
- HexUtils()
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
addHexPrefix(
String hex) → String -
bigIntToHex(
BigInt value, {int? padding}) → String -
bytesToHex(
List< int> bytes, {bool include0x = false}) → String -
decode(
String hex) → Uint8List -
encode(
List< int> bytes, {bool prefix = false}) → String -
hexToBigInt(
String hex) → BigInt -
hexToBytes(
String hex) → Uint8List -
hexToInt(
String hex) → int -
intToHex(
int value, {int? padding}) → String -
isValidHex(
String hex) → bool -
padHex(
String hex, int byteLength) → String -
removeHexPrefix(
String hex) → String