KeystoreV3 class

Implements the Ethereum Keystore V3 specification.

Constructors

KeystoreV3()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

decrypt(Map<String, dynamic> json, String password) Uint8List
Decrypts a Keystore V3 JSON object.
encrypt(Uint8List privateKey, String password, {bool useScrypt = true, String? address, int? n, int? r, int? p}) Map<String, dynamic>
Encrypts a private key using a passphrase.