MpcSigner class abstract

Abstract MPC signer interface.

Implemented types

Constructors

MpcSigner()

Properties

address EthereumAddress
The signer's Ethereum address.
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
partyId String
The party ID in the MPC protocol.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
threshold int
The threshold for signing (t-of-n).
no setter
totalParties int
The total number of parties.
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
refreshKeys() Future<void>
Refreshes key shares.
signAuthorization(Authorization authorization) Future<Uint8List>
Signs an EIP-7702 authorization.
inherited
signHash(Uint8List hash) Future<Uint8List>
Signs a raw hash directly without any prefix.
inherited
signMessage(String message) Future<Uint8List>
Signs a personal message (EIP-191).
inherited
signTransaction(TransactionRequest transaction) Future<Uint8List>
Signs a transaction and returns the signed transaction bytes.
inherited
signTypedData(EIP712TypedData typedData) Future<Uint8List>
Signs typed data (EIP-712).
inherited
startKeyGeneration() Future<void>
Starts a key generation ceremony.
startSigning(Uint8List messageHash) Future<SigningSession>
Starts a signing session.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited