Pbkdf2 class

PBKDF2 (Password-Based Key Derivation Function 2) per RFC 2898.

Used in BIP-39 to derive a 512-bit seed from a mnemonic phrase. BIP-39 specifies: PBKDF2-HMAC-SHA512, 2048 iterations, 64-byte output.

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

deriveKey({required Uint8List password, required Uint8List salt, required int iterations, required int keyLength}) Uint8List
deriveSha256({required Uint8List password, required Uint8List salt, required int iterations, required int keyLength}) Uint8List
Derives a key using PBKDF2-HMAC-SHA512.