RLP class

Recursive Length Prefix (RLP) encoding and decoding.

RLP is the main encoding method used to serialize objects in Ethereum. See: https://ethereum.org/en/developers/docs/data-structures-and-encoding/rlp/

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

decode(Uint8List data) → dynamic
Decodes RLP-encoded data.
encode(dynamic data) Uint8List
Encodes data using RLP encoding.