Signer class abstract

Abstract signer interface for signing transactions and messages.

Constructors

Signer()

Properties

address EthereumAddress
The signer's Ethereum address.
no setter
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
signAuthorization(Authorization authorization) Future<Uint8List>
Signs an EIP-7702 authorization.
signHash(Uint8List hash) Future<Uint8List>
Signs a raw hash directly without any prefix.
signMessage(String message) Future<Uint8List>
Signs a personal message (EIP-191).
signTransaction(TransactionRequest transaction) Future<Uint8List>
Signs a transaction and returns the signed transaction bytes.
signTypedData(EIP712TypedData typedData) Future<Uint8List>
Signs typed data (EIP-712).
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited