SigningSession class

Represents an MPC signing session.

Constructors

SigningSession({required String sessionId, required List<String> requiredParties})

Properties

hashCode int
The hash code for this object.
no setterinherited
requiredParties List<String>
The parties required to complete signing.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sessionId String
The session ID.
final

Methods

cancel() Future<void>
Cancels the signing session.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited
waitForCompletion() Future<Uint8List>
Waits for the signing to complete.

Operators

operator ==(Object other) bool
The equality operator.
inherited