Transaction class
Constructors
- Transaction({EthereumAddress? from, EthereumAddress? to, dynamic maxGas, EtherAmount? gasPrice, EtherAmount? value, Uint8List? data, int? nonce, EtherAmount? maxFeePerGas, EtherAmount? maxPriorityFeePerGas})
- Transaction.callContract({required DeployedContract contract, required ContractFunction function, required List parameters, EthereumAddress? from, dynamic maxGas, EtherAmount? gasPrice, EtherAmount? value, int? nonce, EtherAmount? maxFeePerGas, EtherAmount? maxPriorityFeePerGas})
-
factory
Properties
- data → Uint8List?
-
final
- from → EthereumAddress?
-
final
- gasPrice → EtherAmount?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- maxFeePerGas → EtherAmount?
-
final
- maxGas → BigInt?
-
final
- maxPriorityFeePerGas → EtherAmount?
-
final
- nonce → int?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- to → EthereumAddress?
-
final
- value → EtherAmount?
-
final
Methods
-
copyWith(
{EthereumAddress? from, EthereumAddress? to, dynamic maxGas, EtherAmount? gasPrice, EtherAmount? value, Uint8List? data, int? nonce, EtherAmount? maxFeePerGas, EtherAmount? maxPriorityFeePerGas}) → Transaction -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited