UnitUtils class
Unit conversion utilities
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
etherToWei(
String ether) → BigInt -
fromTokenUnit(
BigInt value, int decimals) → Decimal -
gweiToWei(
String gwei) → BigInt -
toTokenUnit(
Decimal amount, int decimals) → BigInt -
weiToEther(
BigInt wei) → String -
weiToGwei(
BigInt wei) → String