Wallet class

Properties

hashCode int
The hash code for this object.
no setterinherited
privateKey Credentials
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson(String password) Future<String>
Converts the wallet to a Keystore V3 JSON string.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

createNew(Credentials credentials, String password, Random random, {bool useScrypt = true, int? n, int? r, int? p}) Future<String>
Creates a Keystore V3 wallet JSON from the credentials.
fromJson(String jsonStr, String password) Future<Wallet>
Loads a Keystore V3 wallet from JSON.