Web3Client class

Compatibility wrapper for web3dart's Web3Client

Constructors

Web3Client(String rpcUrl, dynamic httpClient, {ChainConfig? chain})

Properties

hashCode int
The hash code for this object.
no setterinherited
rpcUrl String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

call({EthereumAddress? sender, required DeployedContract contract, required ContractFunction function, required List params, BlockNum? atBlock}) Future<List>
dispose() → void
estimateGas({EthereumAddress? sender, EthereumAddress? to, EtherAmount? value, EtherAmount? gasPrice, EtherAmount? maxPriorityFeePerGas, EtherAmount? maxFeePerGas, Uint8List? data}) Future<BigInt>
events(FilterOptions options) Stream<Log>
getBalance(EthereumAddress address) Future<EtherAmount>
getBlockInformation({String blockNumber = 'latest', bool isFull = false}) Future<Block>
getBlockNumber() Future<int>
getChainId() Future<int>
getCode(EthereumAddress address, {BlockNum? atBlock}) Future<Uint8List>
getGasPrice() Future<EtherAmount>
getLogs(FilterOptions options) Future<List<FilterEvent>>
getTransactionCount(EthereumAddress address, {BlockNum? atBlock}) Future<int>
getTransactionReceipt(String hash) Future<TransactionReceipt?>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
sendRawTransaction(Uint8List signedTransaction) Future<String>
sendTransaction(Credentials credentials, Transaction transaction, {int? chainId, bool fetchChainIdFromNetworkId = false}) Future<String>
signTransaction(Credentials credentials, Transaction transaction, {int? chainId, bool fetchChainIdFromNetworkId = false}) Future<Uint8List>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited