Web3PrivateKey class
Legacy compatibility wrapper for PrivateKey (EthPrivateKey).
Constructors
- Web3PrivateKey(Uint8List privateKey)
- Web3PrivateKey.fromHex(String hex)
-
factory
Properties
- address → EthereumAddress
-
no setter
- encodedPublicKey → Uint8List
-
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- privateKey → Uint8List
-
final
- privateKeyInt → BigInt
-
no setter
- publicKey → Uint8List
-
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- signer → Signer
-
no setter
Methods
-
extractAddress(
) → Future< EthereumAddress> -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
signPersonalMessage(
Uint8List message) → Future< Uint8List> -
signToEcSignature(
Uint8List hash) → MsgSignature -
signTransaction(
Transaction transaction, {int? chainId}) → Future< Uint8List> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited