AbiDecoder class
ABI decoder for Ethereum smart contract return values and events.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
decode(
List< AbiType> types, Uint8List data) → List - Decodes data according to the given types.
-
decodeError(
Uint8List data) → String? - Decodes an error message from revert data.
-
decodeEvent(
{required List< AbiType> types, required List<bool> indexed, required List<String> ? names, required List<String> topics, required Uint8List data}) → Map<String, dynamic> - Decodes event log data.
-
decodeFunction(
List< AbiType> outputTypes, Uint8List data) → List - Decodes function return data.