AbiEvent class
Represents an event in an ABI.
Constructors
Properties
- anonymous → bool
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
-
indexed
→ List<
bool> -
final
-
inputNames
→ List<
String> -
final
-
inputs
→ List<
AbiType> -
final
- name → String
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- signature → String
-
Gets the event signature.
no setter
- topic → String
-
Gets the event topic (keccak256 of signature).
no setter
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited