decode method
Decodes a value of this type from data at the given offset. Returns the decoded value and the number of bytes consumed.
Implementation
@override
(dynamic, int) decode(Uint8List data, int offset) {
return (Uint8List.fromList(data.sublist(offset, offset + length)), 32);
}