AbiFunction class
Represents a function in an ABI.
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
-
inputNames
→ List<
String> -
final
-
inputs
→ List<
AbiType> -
final
- isPayable → bool
-
Whether this function is payable.
no setter
- isReadOnly → bool
-
Whether this function is read-only (view or pure).
no setter
- name → String
-
final
-
outputNames
→ List<
String> -
final
-
outputs
→ List<
AbiType> -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- selector → String
-
Gets the 4-byte function selector.
no setter
- signature → String
-
Gets the function signature (e.g., "transfer(address,uint256)").
no setter
- stateMutability → String
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited