decode method

  1. @override
(dynamic, int) decode(
  1. Uint8List data,
  2. int offset
)
override

Decodes a value of this type from data at the given offset. Returns the decoded value and the number of bytes consumed.

Implementation

@override
(dynamic, int) decode(Uint8List data, int offset) {
  final (bytes, consumed) = AbiBytes().decode(data, offset);
  // Decode UTF-8 bytes back to string
  return (utf8.decode(bytes as Uint8List), consumed);
}