AuthorizationVerifier class
Utility class for verifying EIP-7702 authorizations.
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
isValidAuthorizationFormat(
Authorization authorization) → bool - Checks if an authorization is properly formatted.
-
isValidAuthorizationListFormat(
List< Authorization> authorizations) → bool - Checks if all authorizations in a list have valid format.
-
recoverSigner(
Authorization authorization) → String? - Recovers the signer address from an authorization signature.
-
recoverSigners(
List< Authorization> authorizations) → Map<int, String?> - Recovers signer addresses from a list of authorizations.
-
validateAuthorizationListFormat(
List< Authorization> authorizations) → Map<int, bool> - Validates a list of authorizations for format correctness.
-
verifyAllAuthorizations(
List< Authorization> authorizations, List<String> expectedSigners) → bool - Verifies that all authorizations in a list are valid.
-
verifyAuthorization(
Authorization authorization, String expectedSigner) → bool - Verifies a single authorization.
-
verifyAuthorizationList(
List< Authorization> authorizations, List<String> expectedSigners) → Map<int, bool> - Verifies a list of authorizations.