CurveInterface class abstract

Abstract interface for elliptic curve operations.

Provides a common interface for different elliptic curves used in blockchain systems.

Constructors

CurveInterface()

Properties

curveName String
Gets the curve name.
no setter
hashCode int
The hash code for this object.
no setterinherited
privateKeyLength int
Gets the expected private key length in bytes.
no setter
publicKeyLength int
Gets the expected public key length in bytes.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
signatureLength int
Gets the expected signature length in bytes.
no setter

Methods

getPublicKey(Uint8List privateKey) Uint8List
Derives the public key from a private key.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
sign(Uint8List messageHash, Uint8List privateKey) Uint8List
Signs a message hash with the given private key.
toString() String
A string representation of this object.
inherited
verify(Uint8List signature, Uint8List messageHash, Uint8List publicKey) bool
Verifies a signature against a message hash and public key.

Operators

operator ==(Object other) bool
The equality operator.
inherited