Ed25519KeyPair class
Ed25519 key pair.
Constructors
- Ed25519KeyPair(Uint8List privateKey, Uint8List publicKey)
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- privateKey → Uint8List
-
final
- publicKey → Uint8List
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
sign(
Uint8List message) → Uint8List - Signs a message using this key pair.
-
toString(
) → String -
A string representation of this object.
inherited
-
verify(
Uint8List signature, Uint8List message) → bool - Verifies a signature using this key pair's public key.
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited