Log class
Event log.
Constructors
Properties
- address → String
-
final
- blockHash → String
-
final
- blockNumber → BigInt
-
final
- data → Uint8List
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- logIndex → int
-
final
- removed → bool
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
topics
→ List<
String> -
final
- transactionHash → String
-
final
- transactionIndex → int
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited