PublicClientBase class abstract
Base interface for all blockchain clients.
Constructors
Properties
- chain → ChainConfig
-
The chain configuration for this client.
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
dispose(
) → void - Disposes of the client and its underlying resources.
-
getBalance(
String address) → Future< BigInt> - Gets the balance of an address in the native currency's smallest unit. Standardized to BigInt to support diverse precisions.
-
getBlockNumber(
) → Future< BigInt> - Gets the current block (or slot, for SVM) number.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
sendTransaction(
Uint8List tx) → Future< String> - Sends a raw signed transaction to the network.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited