SimulateResult class
Result of a contract function simulation.
Constructors
- SimulateResult({required List result, required BigInt gasUsed, required bool success, String? revertReason})
Properties
- gasUsed → BigInt
-
The estimated gas used.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- result → List
-
The decoded return values.
final
- revertReason → String?
-
The revert reason if the simulation failed.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- success → bool
-
Whether the simulation succeeded.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited