TransactionReceipt class
Transaction receipt.
Constructors
-
TransactionReceipt({required String transactionHash, required int transactionIndex, required String blockHash, required BigInt blockNumber, required String from, required BigInt cumulativeGasUsed, required BigInt gasUsed, required List<
Log> logs, required int status, String? to, String? contractAddress, BigInt? effectiveGasPrice}) -
TransactionReceipt.fromJson(Map<
String, dynamic> json) -
factory
Properties
- blockHash → String
-
final
- blockNumber → BigInt
-
final
- contractAddress → String?
-
final
- cumulativeGasUsed → BigInt
-
final
- effectiveGasPrice → BigInt?
-
final
- from → String
-
final
- gasUsed → BigInt
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
-
logs
→ List<
Log> -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- status → int
-
final
- success → bool
-
Whether the transaction succeeded.
no setter
- to → String?
-
final
- transactionHash → String
-
final
- transactionIndex → int
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited