TransactionRequest class
Represents a transaction request.
Constructors
-
TransactionRequest({String? to, BigInt? value, Uint8List? data, BigInt? gasLimit, BigInt? gasPrice, BigInt? maxFeePerGas, BigInt? maxPriorityFeePerGas, BigInt? nonce, int? chainId, TransactionType type = TransactionType.eip1559, List<
AccessListEntry> ? accessList, List<String> ? blobVersionedHashes, BigInt? maxFeePerBlobGas, List<Authorization> ? authorizationList})
Properties
-
accessList
→ List<
AccessListEntry> ? -
Access list (for EIP-2930+).
final
-
Authorization list (for EIP-7702).
final
-
blobVersionedHashes
→ List<
String> ? -
Blob versioned hashes (for EIP-4844).
final
- chainId → int?
-
The chain ID.
final
- data → Uint8List?
-
The transaction data.
final
- gasLimit → BigInt?
-
The gas limit.
final
- gasPrice → BigInt?
-
The gas price (for legacy transactions).
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- maxFeePerBlobGas → BigInt?
-
Max fee per blob gas (for EIP-4844).
final
- maxFeePerGas → BigInt?
-
The max fee per gas (for EIP-1559+).
final
- maxPriorityFeePerGas → BigInt?
-
The max priority fee per gas (for EIP-1559+).
final
- nonce → BigInt?
-
The nonce.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- to → String?
-
The recipient address (null for contract creation).
final
- type → TransactionType
-
The transaction type.
final
- value → BigInt?
-
The value to send in wei.
final
Methods
-
copyWith(
{String? to, BigInt? value, Uint8List? data, BigInt? gasLimit, BigInt? gasPrice, BigInt? maxFeePerGas, BigInt? maxPriorityFeePerGas, BigInt? nonce, int? chainId, TransactionType? type, List< AccessListEntry> ? accessList, List<String> ? blobVersionedHashes, BigInt? maxFeePerBlobGas, List<Authorization> ? authorizationList}) → TransactionRequest - Creates a copy with updated fields.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited