WalletClientBase class abstract

Base interface for all wallet clients.

Inheritance

Constructors

WalletClientBase()

Properties

address String
The wallet address.
no setter
chain → ChainConfig
The chain configuration for this client.
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

dispose() → void
Disposes of the client and its underlying resources.
inherited
getBalance(String address) Future<BigInt>
Gets the balance of an address in the native currency's smallest unit. Standardized to BigInt to support diverse precisions.
inherited
getBlockNumber() Future<BigInt>
Gets the current block (or slot, for SVM) number.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
sendTransaction(Uint8List tx) Future<String>
Sends a raw signed transaction to the network.
inherited
signMessage(String message) Future<Uint8List>
Signs a message.
signTransaction(Uint8List tx) Future<Uint8List>
Signs a raw transaction.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited