Web3Log class

Constructors

Web3Log(Log _log)

Properties

address EthereumAddress
no setter
blockNum BigInt?
no setter
data String?
no setter
hashCode int
The hash code for this object.
no setterinherited
logIndex int?
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
topics List<String>?
no setter
transactionHash String?
no setter
transactionIndex int?
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited